@@ -8,16 +8,18 @@ from urllib import urlencode
 import requests
 from rauth.hook import OAuth1Hook
 
-from query import Resolve, Table, Submit, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi
+from query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi
 
 API_V3_HOST = "http://api.v3.factual.com"
-DRIVER_VERSION_TAG = "factual-python-driver-1.3.0"
+DRIVER_VERSION_TAG = "factual-python-driver-1.3.1"
 
 class Factual(object):
-    def __init__(self, key, secret):
+    def __init__(self, key, secret, timeout=None):
         self.key = key
         self.secret = secret
-        self.api = API(self._generate_token(key, secret))
+        self.timeout = timeout
+        self.api = API(self._generate_token(key, secret),timeout)
+
 
     def table(self, table):
         return Table(self.api, 't/' + table)
@@ -34,12 +36,18 @@ class Factual(object):
     def raw_read(self, path, raw_params):
         return self.api.raw_read(path, raw_params)
 
+    def raw_write(self, path, raw_params):
+        return self.api.raw_write(path, raw_params)
+
     def facets(self, table):
         return Facets(self.api, 't/' + table + '/facets')
 
     def submit(self, table, factual_id=None, values={}):
         return Submit(self.api, table, factual_id, {'values': values})
 
+    def insert(self, table, factual_id=None, values={}):
+        return Insert(self.api, table, factual_id, {'values': values})
+
     def flag(self, table, factual_id):
         return Flag(self.api, table, factual_id)
 
@@ -64,31 +72,35 @@ class Factual(object):
 
 
 class API(object):
-    def __init__(self, access_token):
-        self.client = requests.session(hooks={'pre_request': access_token})
+    def __init__(self, access_token, timeout):
+        self.client = requests.session(hooks={'pre_request': access_token}, prefetch=False, timeout=timeout)
 
     def get(self, query):
-        response = self._handle_request(query.path, query.params, self.client.get)
+        response = self._handle_request(query.path, query.params, self._make_get_request)
         return response
 
     def post(self, query):
-        response = self._handle_request(query.path, query.params, self.client.post)
+        response = self._handle_request(query.path, query.params, self._make_post_request)
         return response
         
     def schema(self, query):
-        response = self._handle_request(query.path + '/schema', query.params, self.client.get)
+        response = self._handle_request(query.path + '/schema', query.params, self._make_get_request)
         return response['view']
 
     def raw_read(self, path, raw_params):
         url = self._build_base_url(path)
-        return self._make_request(url, raw_params, self.client.get).text
+        return self._make_request(url, raw_params, self._make_get_request).text
 
     def raw_stream_read(self, path, raw_params):
-        url = self._build_base_url(path, raw_params)
-        for line in self._make_request(url, raw_params, self.client.get).iter_lines():
+        url = self._build_base_url(path)
+        for line in self._make_request(url, raw_params, self._make_get_request).iter_lines():
             if line:
                 yield line
 
+    def raw_write(self, path, raw_params):
+        url = self._build_base_url(path)
+        return self._make_request(url, raw_params, self._make_post_request).text
+
     def build_url(self, path, params):
         url = self._build_base_url(path)
         url += '?' + self._make_query_string(params)
@@ -109,13 +121,20 @@ class API(object):
         return payload['response'] if 'response' in payload else payload
 
     def _make_request(self, url, params, request_method):
-        headers = {'X-Factual-Lib': DRIVER_VERSION_TAG}
         request_params = self._transform_params(params)
-        response = request_method(url, headers=headers, params=request_params)
+        response = request_method(url, request_params)
         if not 200 <= response.status_code < 300:
             raise APIException(response.status_code, response.text, response.url)
         return response
 
+    def _make_get_request(self, url, params):
+        headers = {'X-Factual-Lib': DRIVER_VERSION_TAG}
+        return self.client.get(url, headers=headers, params=params)
+
+    def _make_post_request(self, url, params):
+        headers = {'X-Factual-Lib': DRIVER_VERSION_TAG, 'content-type': 'application/x-www-form-urlencoded'}
+        return self.client.post(url, headers=headers, data=params)
+
     def _make_query_string(self, params):
         return urlencode([(k,v) for k,v in self._transform_params(params).items()])
 
