@@ -94,7 +94,7 @@ class FactualAPITestSuite(unittest.TestCase):
     def test_and(self):
         q = self.places.filters({"$and":[{"country":"US"},{"website":{"$blank":False}}]})
         row = q.data()[0]
-        self.assertEqual('US', row['country'])
+        self.assertEqual('US', row['country'].upper())
         self.assertRegexpMatches(row['website'], 'http')
 
     def test_raw_read(self):
@@ -112,6 +112,13 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertEqual(15, payload['response']['included_rows'])
         self.assertTrue(all(row['name'] == 'Starbucks' for row in data))
 
+    def test_raw_write(self):
+        uuid = 'f9ffc74e-c79b-4a28-8d8f-9d484100f148'
+        params = {'problem':'other','user':'python_driver_tester','debug':True}
+        response = self.factual.raw_write('t/t7RSEV/' + uuid + '/flag', params)
+        payload = json.loads(response)
+        self.assertEqual('ok', payload['status'])
+
     def test_facets1(self):
         q = self.facets.search("starbucks").select("country")
         results = q.data()['country']
@@ -155,7 +162,7 @@ class FactualAPITestSuite(unittest.TestCase):
 
     def test_submit_without_id(self):
         values = {'longitude': 100}
-        submit = self.factual.submit('2EH4Pz', values=values).user('python_driver_tester')
+        submit = self.factual.submit('t7RSEV', values=values).user('python_driver_tester')
         response = submit.write()
         if 'new_entity' in response:
             self.assertTrue(response['new_entity'])
@@ -165,7 +172,7 @@ class FactualAPITestSuite(unittest.TestCase):
 
     def test_submit_with_id(self):
         values = {'longitude': 100}
-        submit = self.factual.submit('2EH4Pz', factual_id='0545b03f-9413-44ed-8882-3a9a461848da', values=values).user('python_driver_tester')
+        submit = self.factual.submit('t7RSEV', factual_id='bf6547a8-c0f3-4ada-abf8-9b831bbd5eeb', values=values).user('python_driver_tester')
         response = submit.write()
         if 'new_entity' in response:
             self.assertFalse(response['new_entity'])
@@ -173,9 +180,8 @@ class FactualAPITestSuite(unittest.TestCase):
             self.assertIn('status', response)
             self.assertEqual('warning', response['status'])
 
-
     def test_flag(self):
-        flag = self.factual.flag('2EH4Pz', '0545b03f-9413-44ed-8882-3a9a461848da').user('python_driver_tester').other().debug(True)
+        flag = self.factual.flag('t7RSEV', 'f9ffc74e-c79b-4a28-8d8f-9d484100f148').user('python_driver_tester').other().debug(True)
         response = flag.write()
         self.assertEqual('ok', response['status'])
 
